==> owncloud-8.2.2p3.tgz: owncloud/settings/l10n/eo.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "Kunhavigo",
    "External Storage" : "Malena memorilo",
    "Cron" : "Cron",
    "Log" : "Protokolo",
    "Updates" : "Ĝisdatigoj",
    "Authentication error" : "Aŭtentiga eraro",
    "Your full name has been changed." : "Via plena nomo ŝanĝitas.",
    "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
    "Language changed" : "La lingvo estas ŝanĝita",
    "Invalid request" : "Nevalida peto",
    "Admins can't remove themself from the admin group" : "Administrantoj ne povas forigi sin mem el la administra grupo.",
    "Unable to add user to group %s" : "Ne eblis aldoni la uzanton al la grupo %s",
    "Unable to remove user from group %s" : "Ne eblis forigi la uzantan el la grupo %s",
    "Couldn't update app." : "Ne eblis ĝisdatigi la aplikaĵon.",
    "Wrong password" : "Malĝusta pasvorto",
    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
    "Enabled" : "Kapabligita",
    "Saved" : "Konservita",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Email saved" : "La retpoŝtadreso konserviĝis",
    "Sending..." : "Sendante...",
    "All" : "Ĉio",
    "Please wait...." : "Bonvolu atendi...",
    "Error while disabling app" : "Eraris malkapabligo de aplikaĵo",
    "Disable" : "Malkapabligi",
    "Enable" : "Kapabligi",
    "Error while enabling app" : "Eraris kapabligo de aplikaĵo",
    "Updating...." : "Ĝisdatigata...",
    "Error while updating app" : "Eraris ĝisdatigo de la aplikaĵo",
    "Updated" : "Ĝisdatigita",
    "Uninstalling ...." : "Malinstalante...",
    "Error while uninstalling app" : "Eraris malinstalo de aplikaĵo",
    "Uninstall" : "Malinstali",
    "Select a profile picture" : "Elekti profilan bildon",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Delete" : "Forigi",
    "Groups" : "Grupoj",
    "deleted {groupName}" : "{groupName} foriĝis",
    "undo" : "malfari",
    "never" : "neniam",
    "deleted {userName}" : "{userName} foriĝis",
    "add group" : "aldoni grupon",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "Error creating user" : "Eraris kreo de uzanto",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "__language_name__" : "Esperanto",
    "SSL root certificates" : "Radikaj SSL-atestoj",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Ĉio (fatalaĵoj, eraroj, avertoj, informoj, sencimigaj mesaĝoj)",
    "Info, warnings, errors and fatal issues" : "Informoj, avertoj, eraroj kaj fatalaĵoj",
    "Warnings, errors and fatal issues" : "Avertoj, eraroj kaj fatalaĵoj",
    "Errors and fatal issues" : "Eraroj kaj fatalaĵoj",
    "Fatal issues only" : "Fatalaĵoj nur",
    "None" : "Nenio",
    "Login" : "Ensaluti",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "Open documentation" : "Malfermi la dokumentaron",
    "Allow apps to use the Share API" : "Kapabligi aplikaĵojn uzi la API-on pri Kunhavigo",
    "Allow public uploads" : "Permesi publikajn alŝutojn",
    "Expire after " : "Eksvalidigi post",
    "days" : "tagoj",
    "Allow resharing" : "Kapabligi rekunhavigon",
    "Send mode" : "Sendi pli",
    "Encryption" : "Ĉifrado",
    "From address" : "El adreso",
    "mail" : "retpoŝto",
    "Authentication method" : "Aŭtentiga metodo",
    "Authentication required" : "Aŭtentiĝo nepras",
    "Server address" : "Servila adreso",
    "Port" : "Pordo",
    "Credentials" : "Aŭtentigiloj",
    "SMTP Username" : "SMTP-uzantonomo",
    "SMTP Password" : "SMTP-pasvorto",
    "Send email" : "Sendi retpoŝton",
    "Log level" : "Registronivelo",
    "More" : "Pli",
    "Less" : "Malpli",
    "Version" : "Eldono",
    "by" : "de",
    "Documentation:" : "Dokumentaro:",
    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
    "Uninstall App" : "Malinstali aplikaĵon",
    "Forum" : "Forumo",
    "Get the apps to sync your files" : "Ekhavu la aplikaĵojn por sinkronigi viajn dosierojn",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Vi uzas <strong>%s</strong> el la disponeblaj <strong>%s</strong>",
    "Password" : "Pasvorto",
    "Unable to change your password" : "Ne eblis ŝanĝi vian pasvorton",
    "Current password" : "Nuna pasvorto",
    "New password" : "Nova pasvorto",
    "Change password" : "Ŝanĝi la pasvorton",
    "Email" : "Retpoŝto",
    "Your email address" : "Via retpoŝta adreso",
    "Profile picture" : "Profila bildo",
    "Upload new" : "Alŝuti novan",
    "Select new from Files" : "Elekti novan el dosieroj",
    "Remove image" : "Forigi bildon",
    "Cancel" : "Nuligi",
    "Choose as profile image" : "Elekti kiel profilan bildon",
    "Language" : "Lingvo",
    "Help translate" : "Helpu traduki",
    "Username" : "Uzantonomo",
    "Create" : "Krei",
    "Add Group" : "Aldoni grupon",
    "Group" : "Grupo",
    "Everyone" : "Ĉiuj",
    "Admins" : "Administrantoj",
    "Default Quota" : "Defaŭlta kvoto",
    "Unlimited" : "Senlima",
    "Other" : "Alia",
    "Full Name" : "Plena nomo",
    "Quota" : "Kvoto",
    "Last Login" : "Lasta ensaluto",
    "change full name" : "ŝanĝi plenan nomon",
    "set new password" : "agordi novan pasvorton",
    "Default" : "Defaŭlta"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.4.tgz: owncloud/settings/l10n/eo.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Malĝusta pasvorto",
    "Authentication error" : "Aŭtentiga eraro",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Motoro ne subtenas ŝanĝi pasvorton, sed la ĉifroŝlosilo de la uzanto sukcese ĝisdatiĝis.",
    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
    "Enabled" : "Kapabligita",
    "Federated Cloud Sharing" : "Federnuba kunhavado",
    "Group already exists." : "Grupo jam ekzistas",
    "Saved" : "Konservita",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Email saved" : "La retpoŝtadreso konserviĝis",
    "Your full name has been changed." : "Via plena nomo ŝanĝitas.",
    "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
    "Sharing" : "Kunhavigo",
    "External Storage" : "Malena memorilo",
    "Cron" : "Cron",
    "Email server" : "Retpoŝtoservilo",
    "Log" : "Protokolo",
    "Updates" : "Ĝisdatigoj",
    "Language changed" : "La lingvo estas ŝanĝita",
    "Invalid request" : "Nevalida peto",
    "Admins can't remove themself from the admin group" : "Administrantoj ne povas forigi sin mem el la administra grupo.",
    "Unable to add user to group %s" : "Ne eblis aldoni la uzanton al la grupo %s",
    "Unable to remove user from group %s" : "Ne eblis forigi la uzantan el la grupo %s",
    "Couldn't update app." : "Ne eblis ĝisdatigi la aplikaĵon.",
    "Sending..." : "Sendante...",
    "All" : "Ĉio",
    "Please wait...." : "Bonvolu atendi...",
    "Error while disabling app" : "Eraris malkapabligo de aplikaĵo",
    "Disable" : "Malkapabligi",
    "Enable" : "Kapabligi",
    "Error while enabling app" : "Eraris kapabligo de aplikaĵo",
    "Updating...." : "Ĝisdatigata...",
    "Error while updating app" : "Eraris ĝisdatigo de la aplikaĵo",
    "Updated" : "Ĝisdatigita",
    "Uninstalling ...." : "Malinstalante...",
    "Error while uninstalling app" : "Eraris malinstalo de aplikaĵo",
    "Uninstall" : "Malinstali",
    "Delete" : "Forigi",
    "Select a profile picture" : "Elekti profilan bildon",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Groups" : "Grupoj",
    "deleted {groupName}" : "{groupName} foriĝis",
    "undo" : "malfari",
    "never" : "neniam",
    "deleted {userName}" : "{userName} foriĝis",
    "add group" : "aldoni grupon",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "__language_name__" : "Esperanto",
    "Unlimited" : "Senlima",
    "Personal info" : "Persona informo",
    "Sync clients" : "Sinkronigi klientojn",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Ĉio (fatalaĵoj, eraroj, avertoj, informoj, sencimigaj mesaĝoj)",
    "Info, warnings, errors and fatal issues" : "Informoj, avertoj, eraroj kaj fatalaĵoj",
    "Warnings, errors and fatal issues" : "Avertoj, eraroj kaj fatalaĵoj",
    "Errors and fatal issues" : "Eraroj kaj fatalaĵoj",
    "Fatal issues only" : "Fatalaĵoj nur",
    "None" : "Nenio",
    "Login" : "Ensaluti",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "Open documentation" : "Malfermi la dokumentaron",
    "Allow apps to use the Share API" : "Kapabligi aplikaĵojn uzi la API-on pri Kunhavigo",
    "Allow users to share via link" : "Permesi uzantojn kunhavigi ligile",
    "Allow public uploads" : "Permesi publikajn alŝutojn",
    "Expire after " : "Eksvalidigi post",
    "days" : "tagoj",
    "Allow resharing" : "Kapabligi rekunhavigon",
    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas kapabligi ĉifradon?",
    "Enable encryption" : "Kapabligi ĉifradon",
    "Send mode" : "Sendi pli",
    "Encryption" : "Ĉifrado",
    "From address" : "El adreso",
    "mail" : "retpoŝto",
    "Authentication method" : "Aŭtentiga metodo",
    "Authentication required" : "Aŭtentiĝo nepras",
    "Server address" : "Servila adreso",
    "Port" : "Pordo",
    "Credentials" : "Aŭtentigiloj",
    "SMTP Username" : "SMTP-uzantonomo",
    "SMTP Password" : "SMTP-pasvorto",
    "Test email settings" : "Provi retpoŝtagordon",
    "Send email" : "Sendi retpoŝton",
    "Download logfile" : "Elŝuti protokoldosiero",
    "More" : "Pli",
    "Less" : "Malpli",
    "What to log" : "Kion protokoli",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite uziĝas kiel datumbazo. Por pli grandaj instaloj ni rekomendas ŝanĝi ĝin per malsama datumbazomotoro.",
    "Version" : "Eldono",
    "by %s" : "de %s",
    "%s-licensed" : "%s-permesila",
    "Documentation:" : "Dokumentaro:",
    "User documentation" : "Uzodokumentaro",
    "Admin documentation" : "Administrodokumentaro",
    "Show description …" : "Montri priskribon...",
    "Hide description …" : "Malmontri priskribon...",
    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
    "Uninstall App" : "Malinstali aplikaĵon",
    "Common Name" : "Komuna nomo",
    "Valid until" : "Valida ĝis",
    "Valid until %s" : "Valida ĝis %s",
    "Administrator documentation" : "Administrodokumentaro",
    "Forum" : "Forumo",
    "Commercial support" : "Komerca subteno",
    "Profile picture" : "Profila bildo",
    "Upload new" : "Alŝuti novan",
    "Select from Files" : "Elekti el Dosieroj",
    "Remove image" : "Forigi bildon",
    "Cancel" : "Nuligi",
    "Full name" : "Plena nomo",
    "Email" : "Retpoŝto",
    "Your email address" : "Via retpoŝta adreso",
    "Password" : "Pasvorto",
    "Unable to change your password" : "Ne eblis ŝanĝi vian pasvorton",
    "Current password" : "Nuna pasvorto",
    "New password" : "Nova pasvorto",
    "Change password" : "Ŝanĝi la pasvorton",
    "Language" : "Lingvo",
    "Help translate" : "Helpu traduki",
    "Name" : "Nomo",
    "Username" : "Uzantonomo",
    "Done" : "Farita",
    "Get the apps to sync your files" : "Ekhavu la aplikaĵojn por sinkronigi viajn dosierojn",
    "Desktop client" : "Labortabla kliento",
    "Android app" : "Android-aplikaĵo",
    "iOS app" : "iOS-aplikaĵo",
    "Show last log in" : "Montri lastan ensaluton",
    "Show user backend" : "Montri uzantomotoron",
    "E-Mail" : "Retpoŝtadreso",
    "Create" : "Krei",
    "Add Group" : "Aldoni grupon",
    "Group" : "Grupo",
    "Everyone" : "Ĉiuj",
    "Admins" : "Administrantoj",
    "Default Quota" : "Defaŭlta kvoto",
    "Other" : "Alia",
    "Full Name" : "Plena nomo",
    "Group Admin for" : "Grupadministranto en",
    "Quota" : "Kvoto",
    "User Backend" : "Uzantomotoro",
    "Last Login" : "Lasta ensaluto",
    "change full name" : "ŝanĝi plenan nomon",
    "set new password" : "agordi novan pasvorton",
    "change email address" : "ŝanĝi retpoŝtadreson",
    "Default" : "Defaŭlta"
},
"nplurals=2; plural=(n != 1);");
